Package: bfpwr
Version: 0.1.6
Date: 2025-09-02
Authors@R: 
    c(person(given = "Samuel",
           family = "Pawel",
           role = c("aut", "cre"),
           email = "samuel.pawel@uzh.ch",
           comment = c(ORCID = "0000-0003-2779-320X")))
Author: Samuel Pawel [aut, cre] (ORCID:
    <https://orcid.org/0000-0003-2779-320X>)
Maintainer: Samuel Pawel <samuel.pawel@uzh.ch>
Title: Power and Sample Size Calculations for Bayes Factor Analysis
Description: Implements z-test, t-test, and normal moment prior Bayes factors based on summary statistics, along with functionality to perform corresponding power and sample size calculations as described in Pawel and Held (2025) <doi:10.1080/00031305.2025.2467919>.
License: GPL-3
Encoding: UTF-8
Imports: lamW
Suggests: roxygen2, tinytest, knitr
VignetteBuilder: knitr
NeedsCompilation: no
RoxygenNote: 7.3.2
URL: https://github.com/SamCH93/bfpwr
BugReports: https://github.com/SamCH93/bfpwr/issues
Packaged: 2025-09-02 15:16:51 UTC; sam
Repository: CRAN
Date/Publication: 2025-09-02 16:10:02 UTC
Built: R 4.6.0; ; 2026-04-25 16:59:28 UTC; unix
