# Generated by roxygen2: do not edit by hand

S3method(plot,power.bftest)
S3method(print,power.bftest)
export(bf01)
export(binbf01)
export(nbf01)
export(nbinbf01)
export(nmbf01)
export(nnmbf01)
export(ntbf01)
export(pbf01)
export(pbinbf01)
export(pnmbf01)
export(powerbf01)
export(powerbinbf01)
export(powernmbf01)
export(powertbf01)
export(ptbf01)
export(tbf01)
